@@ -1483,7 +1483,7 @@ static constexpr OUString continuousStyle7[] = {
 };
 
 
-static const OUString* LCContinuousNumberingLevelsArray[] = {
+static const OUString* const LCContinuousNumberingLevelsArray[] = {
 	continuousStyle0,
 	continuousStyle1,
 	continuousStyle2,
